==> librepcb-0.1.7-source.zip: librepcb-0.1.7/libs/librepcb/core/library/libraryelementcheck.cpp <==
/*
 * LibrePCB - Professional EDA for everyone!
 * Copyright (C) 2013 LibrePCB Developers, see AUTHORS.md for contributors.
 * https://librepcb.org/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*******************************************************************************
 *  Includes
 ******************************************************************************/
#include "libraryelementcheck.h"

#include "libraryelement.h"
#include "msg/msgmissingcategories.h"

#include <QtCore>

/*******************************************************************************
 *  Namespace
 ******************************************************************************/
namespace librepcb {

/*******************************************************************************
 *  Constructors / Destructor
 ******************************************************************************/

LibraryElementCheck::LibraryElementCheck(const LibraryElement& element) noexcept
  : LibraryBaseElementCheck(element), mElement(element) {
}

LibraryElementCheck::~LibraryElementCheck() noexcept {
}

/*******************************************************************************
 *  General Methods
 ******************************************************************************/

LibraryElementCheckMessageList LibraryElementCheck::runChecks() const {
  LibraryElementCheckMessageList msgs = LibraryBaseElementCheck::runChecks();
  checkMissingCategories(msgs);
  return msgs;
}

/*******************************************************************************
 *  Protected Methods
 ******************************************************************************/

void LibraryElementCheck::checkMissingCategories(MsgList& msgs) const {
  if (mElement.getCategories().isEmpty()) {
    msgs.append(std::make_shared<MsgMissingCategories>());
  }
}

/*******************************************************************************
 *  End of File
 ******************************************************************************/

}  // namespace librepcb

==> librepcb-1.2.0-source.zip: librepcb-1.2.0/libs/librepcb/core/library/libraryelementcheck.cpp <==
/*
 * LibrePCB - Professional EDA for everyone!
 * Copyright (C) 2013 LibrePCB Developers, see AUTHORS.md for contributors.
 * https://librepcb.org/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*******************************************************************************
 *  Includes
 ******************************************************************************/
#include "libraryelementcheck.h"

#include "libraryelement.h"
#include "libraryelementcheckmessages.h"

#include <QtCore>

/*******************************************************************************
 *  Namespace
 ******************************************************************************/
namespace librepcb {

/*******************************************************************************
 *  Constructors / Destructor
 ******************************************************************************/

LibraryElementCheck::LibraryElementCheck(const LibraryElement& element) noexcept
  : LibraryBaseElementCheck(element), mElement(element) {
}

LibraryElementCheck::~LibraryElementCheck() noexcept {
}

/*******************************************************************************
 *  General Methods
 ******************************************************************************/

RuleCheckMessageList LibraryElementCheck::runChecks() const {
  RuleCheckMessageList msgs = LibraryBaseElementCheck::runChecks();
  checkMissingCategories(msgs);
  return msgs;
}

/*******************************************************************************
 *  Protected Methods
 ******************************************************************************/

void LibraryElementCheck::checkMissingCategories(MsgList& msgs) const {
  if (mElement.getCategories().isEmpty()) {
    msgs.append(std::make_shared<MsgMissingCategories>());
  }
}

/*******************************************************************************
 *  End of File
 ******************************************************************************/

}  // namespace librepcb
